@@ -11,7 +11,7 @@ CALIBRATION_CONFIG_FILE = CONFIG + 'calibration/config.txt'
 # HAP_PYTHON_CHARACTERISTICS_FILE="""/home/lesserdaemon/.hap-python/OpenHub/characteristics.json"""
 HAP_PYTHON_CHARACTERISTICS_FILE=os.path.dirname(__file__) + """/characteristics.json"""
 # HAP_PYTHON_SERVICES_FILE="""/home/lesserdaemon/.hap-python/OpenHub/services.json"""
-HAP_PYTHON_SERVICES_FILE=os.path.dirname(__file__)+"""services.json"""
+HAP_PYTHON_SERVICES_FILE=os.path.dirname(__file__)+"""/services.json"""
 
 
 HAP_PYTHON_ACCESSORIES_FILE="""~/accessory.state"""
