@@ -1,6 +1,6 @@
 import json
 
-from globals import id_hardware_map
+from OpenHub.globals import id_hardware_map
 
 from hardware_interfaces.base_io.base_io_interface import BaseIOInterface
 
