@@ -1,12 +1,15 @@
 import json
-from hardware_interfaces.channels.dht22_humidity import DHT22Humidity
-from hardware_interfaces.channels.dht22_temp import DHT22Temp
-from hardware_interfaces.channels.mcp3008analog import MCP3008Analog
-from hardware_interfaces.channels.mod_probe_temp import ModProbeTemp
-from hardware_interfaces.channels.pi_pico_analog import PiPicoAnalog
-from hardware_interfaces.channels.pi_pico_pump import PiPicoPump
-from hardware_interfaces.channels.veml7700_light import VEML7700Light
-from hardware_interfaces.channels.veml7700_lux import VEML7700Lux
+from OpenHub.hardware_interfaces.channels.dht22_humidity import DHT22Humidity
+from OpenHub.hardware_interfaces.channels.dht22_temp import DHT22Temp
+from OpenHub.hardware_interfaces.channels.mcp3008analog import MCP3008Analog
+from OpenHub.hardware_interfaces.channels.mod_probe_temp import ModProbeTemp
+from OpenHub.hardware_interfaces.channels.pi_pico_analog import PiPicoAnalog
+from OpenHub.hardware_interfaces.channels.pi_pico_pump import PiPicoPump
+from OpenHub.hardware_interfaces.channels.veml7700_light import VEML7700Light
+from OpenHub.hardware_interfaces.channels.veml7700_lux import VEML7700Lux
+
+from OpenHub.hardware_interfaces.channels.pi_pico_relay import PiPicoRelay
+
 
 class ChannelDecoder(json.JSONDecoder):
     def __init__(self, *args, **kwargs):
@@ -30,6 +33,9 @@ class ChannelDecoder(json.JSONDecoder):
         elif type == PiPicoPump.__name__:
             return PiPicoPump(dct)
 
+        elif type == PiPicoRelay.__name__:
+            return PiPicoRelay(dct)
+
         elif type == VEML7700Light.__name__:
             return VEML7700Light()
 
