@@ -1,5 +1,5 @@
 import json
-from hardware_interfaces.channels import ChannelInterface
+from OpenHub.hardware_interfaces.channels.channel_interface import ChannelInterface
 
 
 class ChannelEncoder(json.JSONEncoder):
