@@ -1,5 +1,5 @@
 from adafruit_mcp3xxx.analog_in import AnalogIn
-from hardware_interfaces.channels.channel_interface import ChannelInterface
+from .channel_interface import ChannelInterface
 import logging
 import uuid
 
