@@ -1,8 +1,8 @@
 import json
 
-from hardware_interfaces.channels.channel_interface import ChannelInterface
+from .channel_interface import ChannelInterface
 import logging
-from globals import id_hardware_map
+from OpenHub.globals import id_hardware_map
 
 
 class PiPicoAnalog(ChannelInterface):
