@@ -1,6 +1,6 @@
-from hardware_interfaces.channels.channel_interface import ChannelInterface
+from .channel_interface import ChannelInterface
 import logging
-from globals import id_hardware_map
+from OpenHub.globals import id_hardware_map
 
 
 class PiPicoPump(ChannelInterface):
