@@ -1,4 +1,4 @@
-from hardware_interfaces.channels.channel_interface import ChannelInterface
+from .channel_interface import ChannelInterface
 import logging
 
 
