@@ -1,6 +1,6 @@
 from abc import ABC, abstractmethod
 import uuid
-from globals import id_hardware_map
+from OpenHub.globals import id_hardware_map
 
 
 class HardwareInterface(ABC):
