@@ -1,12 +1,12 @@
 import json
 
-from hardware_interfaces.channels.pi_pico_analog import PiPicoAnalog
-from hardware_interfaces.dht22 import DHT22
-from hardware_interfaces.mcp3008 import MCP3008
-from hardware_interfaces.mod_probe import ModProbe
-from hardware_interfaces.pi_pico import PiPico
-from hardware_interfaces.veml_7700 import VEML7700
-from hardware_interfaces.channels.json.channel_decoder import ChannelDecoder
+from OpenHub.hardware_interfaces.channels.pi_pico_analog import PiPicoAnalog
+from OpenHub.hardware_interfaces.dht22 import DHT22
+from OpenHub.hardware_interfaces.mcp3008 import MCP3008
+from OpenHub.hardware_interfaces.mod_probe import ModProbe
+from OpenHub.hardware_interfaces.pi_pico import PiPico
+from OpenHub.hardware_interfaces.veml_7700 import VEML7700
+from OpenHub.hardware_interfaces.channels.json.channel_decoder import ChannelDecoder
 
 
 class HardwareDecoder(json.JSONDecoder):
