@@ -1,6 +1,6 @@
 import json
-from hardware_interfaces.hardware_interface import HardwareInterface
-from hardware_interfaces.channels.json.channel_encoder import ChannelEncoder
+from OpenHub.hardware_interfaces.hardware_interface import HardwareInterface
+from OpenHub.hardware_interfaces.channels.json.channel_encoder import ChannelEncoder
 
 
 class HardwareEncoder(json.JSONEncoder):
