@@ -3,8 +3,8 @@ import digitalio
 import board
 import adafruit_mcp3xxx.mcp3008 as MCP
 import logging
-from hardware_interfaces import hardware_interface
-from hardware_interfaces.channels.mcp3008analog import MCP3008Analog
+from OpenHub.hardware_interfaces import hardware_interface
+from OpenHub.hardware_interfaces.channels.mcp3008analog import MCP3008Analog
 
 
 class MCP3008(hardware_interface.HardwareInterface):
