@@ -1,6 +1,6 @@
 import glob
-from hardware_interfaces.hardware_interface import HardwareInterface
-from hardware_interfaces.channels.mod_probe_temp import ModProbeTemp
+from .hardware_interface import HardwareInterface
+from .channels.mod_probe_temp import ModProbeTemp
 
 
 # os.system('modprobe w1-gpio')
