@@ -1,9 +1,9 @@
 import board
 import busio
 import adafruit_veml7700
-from hardware_interfaces.hardware_interface import HardwareInterface
-from hardware_interfaces.channels.veml7700_light import VEML7700Light
-from hardware_interfaces.channels.veml7700_lux import VEML7700Lux
+from .hardware_interface import HardwareInterface
+from .channels.veml7700_light import VEML7700Light
+from .channels.veml7700_lux import VEML7700Lux
 
 
 class VEML7700(HardwareInterface):
