@@ -1,5 +1,5 @@
 import logging
-from homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface
+from OpenHub.homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface
 
 
 class AirTemperatureSensor(HomeKitSensorInterface):
@@ -11,8 +11,10 @@ class AirTemperatureSensor(HomeKitSensorInterface):
                          channel_interface_serial_no=channel_interface_serial_no, *args, **kwargs)
 
     def set_display_name(self, display_name):
-        if self.display_name is None:
+        if display_name is None:
             return display_name + "Air Temperature"
+        else:
+            return display_name
 
     def add_functional_service(self):
         return self.add_preload_service('TemperatureSensor')
