@@ -1,4 +1,4 @@
-from homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface
+from OpenHub.homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface
 import logging
 
 class ETapeSensor(HomeKitSensorInterface):
@@ -12,8 +12,10 @@ class ETapeSensor(HomeKitSensorInterface):
                          channel_interface_serial_no=channel_interface_serial_no, *args, **kwargs)
 
     def set_display_name(self, display_name):
-        if self.display_name is None:
+        if display_name is None:
             return "ETape"
+        else:
+            return display_name
 
     def add_functional_service(self):
         return self.add_preload_service("PressureSensor")
