@@ -1,7 +1,7 @@
 import json
-from hardware_interfaces.channels.json.channel_encoder import ChannelEncoder
+from OpenHub.hardware_interfaces.channels.json.channel_encoder import ChannelEncoder
 
-from hardware_interfaces.channels.channel_interface import ChannelInterface
+from OpenHub.hardware_interfaces.channels.channel_interface import ChannelInterface
 
 
 class HomekitEncoder(json.JSONEncoder):
