@@ -1,6 +1,6 @@
 from pyhap.const import CATEGORY_OTHER
 
-from homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface
+from OpenHub.homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface
 import logging
 
 
@@ -16,8 +16,11 @@ class LiquidLevelSensor(HomeKitSensorInterface):
                          channel_interface_serial_no=channel_interface_serial_no, *args, **kwargs)
 
     def set_display_name(self, display_name):
-        if self.display_name is None:
-            return display_name + "LiquidLevel"
+        if display_name is None:
+            return "Liquid Level"
+        else:
+            return display_name
+
 
     def add_functional_service(self):
         return self.add_preload_service("PressureSensor")
