@@ -1,6 +1,6 @@
 import asyncio
 
-from homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface
+from OpenHub.homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface
 import logging
 
 from pyhap.const import CATEGORY_SWITCH
@@ -19,8 +19,10 @@ class Pump(HomeKitSensorInterface):
                          channel_interface_serial_no=channel_interface_serial_no, *args, **kwargs)
 
     def set_display_name(self, display_name):
-        if self.display_name is None:
-            return display_name + "Pump"
+        if display_name is None:
+            return "Pump"
+        else:
+            return display_name
 
     def add_functional_service(self):
         return self.add_preload_service('Pump')
