@@ -1,4 +1,4 @@
-from globals import accessories
+from OpenHub.globals import accessories
 
 for accessory in accessories:
     if accessory.calibrator != None:
