@@ -1,6 +1,6 @@
 from .hardware import first_time_setup
 from .homekit_interfaces import first_time_kit_setup
-from globals import id_hardware_map
+from OpenHub.globals import id_hardware_map
 
 
 def first_run():
