@@ -1,4 +1,4 @@
-from globals import id_hardware_map
+from OpenHub.globals import id_hardware_map
 from hardware_interfaces.json import HardwareDecoder
 import json
 
