@@ -1,6 +1,6 @@
 from pyhap.const import STANDALONE_AID
-from globals import id_hardware_map
-from homekit_accessories.json import HomekitDecoder
+from OpenHub.globals import id_hardware_map
+from OpenHub.homekit_accessories.json import HomekitDecoder
 import json
 
 
